==> ants_2.0.0.orig.tar.gz: ants-2.0.0/Examples/include/ants.h <==
#ifndef ants_h
#define ants_h

#include "antsApplyTransforms.h"

#include "antsAlignOrigin.h"

#include "antsApplyTransformsToPoints.h"

#include "ANTSConformalMapping.h"

#include "ANTS_.h"

#include "ANTSIntegrateVectorField.h"

#include "ANTSIntegrateVelocityField.h"

#include "ANTSJacobian.h"

#include "ants_moco.h"

#include "antsMotionCorr.h"

#include "antsRegistration.h"

#include "ANTSUseDeformationFieldToGetAffineTransform.h"

#include "ANTSUseLandmarkImagesToGetAffineTransform.h"

#include "ANTSUseLandmarkImagesToGetBSplineDisplacementField.h"

#include "Atropos.h"

#include "AtroposMin.h"

#include "AverageAffineTransform.h"

#include "AverageAffineTransformNoRigid.h"

#include "AverageImages.h"

#include "AverageTensorImages.h"

#include "CheckTopology.h"

#include "ClusterImageStatistics.h"

#include "ComposeMultiTransform.h"

#include "CompositeTransformUtil.h"

#include "ComputeSimilarityMetric.h"

#include "ConformalMapping.h"

#include "ConvertImagePixelType.h"

#include "ConvertScalarImageToRGB.h"

#include "ConvertToJpg.h"

#include "ConvertVectorFieldToVTK.h"

#include "CopyImageHeaderInformation.h"

#include "CreateDisplacementField.h"

#include "CreateDTICohort.h"

#include "CreateImage.h"

#include "CreateJacobianDeterminantImage.h"

#include "CreateWarpedGridImage.h"

#include "ExtractRegionFromImageByMask.h"

#include "ExtractRegionFromImage.h"

#include "ExtractSliceFromImage.h"

#include "GetMeshAndTopology.h"

#include "ImageCompare.h"

#include "ImageMath.h"

#include "antsAffineInitializer.h"

#include "ImageSetStatistics.h"

#include "itkCommandLineParserTest.h"

#include "KellyKapowski.h"

#include "KellySlater.h"

#include "LabelClustersUniquely.h"

#include "LabelGeometryMeasures.h"

#include "LabelOverlapMeasures.h"

#include "LaplacianThickness.h"

#include "MeasureImageSimilarity.h"

#include "MeasureMinMaxMean.h"

#include "MemoryTest.h"

#include "MultiplyImages.h"

#include "N3BiasFieldCorrection.h"

#include "N4BiasFieldCorrection.h"

#include "PasteImageIntoImage.h"

#include "PermuteFlipImageOrientationAxes.h"

#include "PrintHeader.h"

#include "RebaseTensorImage.h"

#include "ReorientTensorImage.h"

#include "ResampleImageBySpacing.h"

#include "ResampleImage.h"

#include "ResetDirection.h"

#include "sccan.h"

#include "simpleSynRegistration.h"

#include "SetDirectionByMatrix.h"

#include "SetOrigin.h"

#include "SetSpacing.h"

#include "SmoothImage.h"

#include "StackSlices.h"

#include "StudentsTestOnImages.h"

#include "SurfaceBasedSmoothing.h"

#include "SurfaceCurvature.h"

#include "TensorDerivedImage.h"

#include "ThresholdImage.h"

#include "TileImages.h"

#include "TimeSCCAN.h"

#include "WarpImageMultiTransform.h"

#include "WarpTensorImageMultiTransform.h"

#include "WarpTimeSeriesImageMultiTransform.h"

#include "WarpVTKPolyDataMultiTransform.h"

#include "ConvertTransformFile.h"

#include "compareTwoCompositeTransforms.h"

#endif // ants_h

==> ants_2.1.0.orig.tar.gz: ants-2.1.0/Examples/include/ants.h <==
#ifndef ants_h
#define ants_h

#include "antsApplyTransforms.h"

#include "antsAlignOrigin.h"

#include "antsApplyTransformsToPoints.h"

#include "antsTransformInfo.h"

#include "ANTSConformalMapping.h"

#include "ANTS_.h"

#include "ANTSIntegrateVectorField.h"

#include "ANTSIntegrateVelocityField.h"

#include "ANTSJacobian.h"

#include "ants_moco.h"

#include "antsMotionCorr.h"

#include "antsMotionCorrStats.h"

#include "antsMotionCorrDiffusionDirection.h"

#include "antsSliceRegularizedRegistration.h"

#include "antsRegistration.h"

#include "antsSurf.h"

#include "antsUtilitiesTesting.h"

#include "ANTSUseDeformationFieldToGetAffineTransform.h"

#include "ANTSUseLandmarkImagesToGetAffineTransform.h"

#include "ANTSUseLandmarkImagesToGetBSplineDisplacementField.h"

#include "Atropos.h"

#include "AverageAffineTransform.h"

#include "AverageAffineTransformNoRigid.h"

#include "AverageImages.h"

#include "AverageTensorImages.h"

#include "CheckTopology.h"

#include "ClusterImageStatistics.h"

#include "ComposeMultiTransform.h"

#include "CompositeTransformUtil.h"

#include "ComputeSimilarityMetric.h"

#include "ConformalMapping.h"

#include "ConvertImagePixelType.h"

#include "ConvertInputImagePixelTypeToFloat.h"

#include "ConvertScalarImageToRGB.h"

#include "ConvertToJpg.h"

#include "ConvertVectorFieldToVTK.h"

#include "CopyImageHeaderInformation.h"

#include "CreateDisplacementField.h"

#include "CreateDTICohort.h"

#include "CreateImage.h"

#include "CreateJacobianDeterminantImage.h"

#include "CreateTiledMosaic.h"

#include "CreateWarpedGridImage.h"

#include "DeNrrd.h"

#include "ExtractRegionFromImageByMask.h"

#include "ExtractRegionFromImage.h"

#include "ExtractSliceFromImage.h"

#include "FitBSplineCurveToPoints.h"

#include "GetMeshAndTopology.h"

#include "ImageCompare.h"

#include "ImageMath.h"

#include "ImageIntensityStatistics.h"

#include "antsAffineInitializer.h"

// #include "antsSimilarityInitializer.h"

#include "ImageSetStatistics.h"

#include "itkCommandLineParserTest.h"

#include "KellyKapowski.h"

#include "KellySlater.h"

#include "LabelClustersUniquely.h"

#include "LabelGeometryMeasures.h"

#include "LabelOverlapMeasures.h"

#include "LaplacianThickness.h"

#include "LesionFilling.h"

#include "MeasureImageSimilarity.h"

#include "MeasureMinMaxMean.h"

#include "MemoryTest.h"

#include "MultiplyImages.h"

#include "N3BiasFieldCorrection.h"

#include "N4BiasFieldCorrection.h"

#include "PasteImageIntoImage.h"

#include "PermuteFlipImageOrientationAxes.h"

#include "PrintHeader.h"

#include "RebaseTensorImage.h"

#include "ReorientTensorImage.h"

#include "ResampleImageBySpacing.h"

#include "ResampleImage.h"

#include "ResetDirection.h"

#include "sccan.h"

#include "simpleSynRegistration.h"

#include "SetDirectionByMatrix.h"

#include "SetOrigin.h"

#include "SetSpacing.h"

#include "SmoothImage.h"

#include "StackSlices.h"

#include "StudentsTestOnImages.h"

#include "SurfaceBasedSmoothing.h"

#include "SurfaceCurvature.h"

#include "TensorDerivedImage.h"

#include "ThresholdImage.h"

#include "TileImages.h"

#include "TimeSCCAN.h"

#include "WarpImageMultiTransform.h"

#include "WarpTensorImageMultiTransform.h"

#include "WarpTimeSeriesImageMultiTransform.h"

#include "WarpVTKPolyDataMultiTransform.h"

#include "ConvertTransformFile.h"

#include "compareTwoTransforms.h"

#include "GetConnectedComponentsFeatureImages.h"

#include "TextureRunLengthFeatures.h"

#include "TextureCooccurrenceFeatures.h"

#endif // ants_h
